6-Field Simple
==============

High-Beta Flute-Reduced MHD with 6-field of (`N_i`, `T_e`, `T_i`, `U`, `Psi`,
`Vipar`). This is a simple model for the BOUT++ workshop 2013 hand-on
exercise. Basically the same as Hazeltine-Meiss but different
normalisations. `diffusion_par` can turn on the parallel thermal conductivity
